==> haskell-resourcet-1.2.6-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resourcet
version:              1.2.6
visibility:           public
id:                   resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI
key:                  resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  33fa986300451cd0a0614a238543c00b
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resourcet
hs-libraries:         HSresourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5 mtl-2.2.2
    primitive-0.8.0.0-2MtTSGoMYmP3ESqdIhZDu7 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resourcet-1.2.6-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resourcet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resourcet
version:              1.2.6
visibility:           public
id:                   resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
key:                  resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Deterministic allocation and freeing of scarce resources.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/resourcet>.

category:             Data, Conduit
abi:                  7f1769a633f1c6315fa44f348a62aa5a
exposed:              True
exposed-modules:
    Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
    Data.Acquire Data.Acquire.Internal UnliftIO.Resource

import-dirs:          /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resourcet-1.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resourcet
hs-libraries:         HSresourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
depends:
    base-4.17.2.1 containers-0.6.7 exceptions-0.10.5 mtl-2.2.2
    primitive-0.8.0.0-1110YmBHzhAERV5HY7EG3e transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-resourcet/html/resourcet.haddock
haddock-html:         /usr/share/doc/haskell-resourcet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
